"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const privilegeService = require("../../privilege/service");
const hal = require("../formats/hal");
const userService = require("../service");
const groupService = require("../../group/service");
const http_errors_1 = require("@curveball/http-errors");
class UserController extends controller_1.default {
    async get(ctx) {
        const user = await userService.findById(+ctx.params.id);
        let hasControl = false;
        let hasPassword = false;
        const isAdmin = await privilegeService.hasPrivilege(ctx, 'admin');
        if (ctx.state.user.id === user.id) {
            hasControl = true;
        }
        else if (isAdmin) {
            hasControl = true;
        }
        if (hasControl && user.type === 'user') {
            hasPassword = await userService.hasPassword(user);
        }
        ctx.response.body = hal.item(user, await privilegeService.getPrivilegesForPrincipal(user), hasControl, hasPassword, isAdmin, await groupService.findGroupsForPrincipal(user));
    }
    async put(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege may edit users');
        }
        const user = await userService.findById(+ctx.params.id);
        user.active = !!ctx.request.body.active;
        user.nickname = ctx.request.body.nickname;
        await userService.save(user);
        ctx.status = 204;
    }
}
exports.default = new UserController();
//# sourceMappingURL=item.js.map