declare type Settings = {
    'login.defaultRedirect': string;
    'registration.enabled': boolean;
    'registration.mfa.enabled': boolean;
    'cors.allowOrigin': string[] | null;
    'smtp.url': null | string;
    'smtp.emailFrom': null | string;
    'oauth2.code.expiry': number;
    'oauth2.accessToken.expiry': number;
    'oauth2.refreshToken.expiry': number;
    'jwt.privateKey': string | null;
    'totp': 'enabled' | 'required' | 'disabled';
    'totp.serviceName': string;
    'webauthn': 'enabled' | 'disabled' | 'required';
    'webauthn.expectedOrigin': string | null;
    'webauthn.relyingPartyId': string | null;
    'webauthn.serviceName': string;
    'logo_url': string;
};
/**
 * Retrieves the value of a single setting, by name
 */
export declare function getSetting<T extends keyof Settings>(setting: T): Settings[T];
/**
 * Retrieves the value of a single setting, by name.
 *
 * If the setting was not provided (null) this function will throw an exception.
 */
export declare function requireSetting<T extends keyof Settings>(setting: T): Settings[T];
/**
 * Loads or reloads settings from the database.
 */
export declare function load(): Promise<void>;
export {};
